[NIFI-5219] This closes #3. update project name to NiFi Flow Design System

Signed-off-by: joewitt <joewitt@apache.org>
diff --git a/.github/PULL_REQUEST_TEMPLATE.md b/.github/PULL_REQUEST_TEMPLATE.md
index 06d8a85..426a211 100644
--- a/.github/PULL_REQUEST_TEMPLATE.md
+++ b/.github/PULL_REQUEST_TEMPLATE.md
@@ -1,4 +1,4 @@
-Thank you for submitting a contribution to Apache NiFi Fluid Design System.
+Thank you for submitting a contribution to Apache NiFi Flow Design System.
 
 In order to streamline the review of the contribution we ask you
 to ensure the following steps have been taken:
@@ -16,7 +16,7 @@
 ### For code changes:
 - [ ] Have you written or updated unit tests to verify your changes?
 - [ ] Have you ensured that a full build and that the full suite of unit tests is executed via npm run clean:install at the root nifi-fds folder?
-- [ ] Have you written or updated the Apache NiFi Fluid Design System demo application to demonstrate any new functionality, provide examples of usage, and to verify your changes via npm start at the nifi-fds/target folder?
+- [ ] Have you written or updated the Apache NiFi Flow Design System demo application to demonstrate any new functionality, provide examples of usage, and to verify your changes via npm start at the nifi-fds/target folder?
 - [ ] If adding new dependencies to the code, are these dependencies licensed in a way that is compatible for inclusion under [ASF 2.0](http://www.apache.org/legal/resolved.html#category-a)?
 - [ ] If applicable, have you updated the LICENSE file, including the main LICENSE file under nifi-fds?
 - [ ] If applicable, have you updated the NOTICE file, including the main NOTICE file found under nifi-fds?
diff --git a/Gruntfile.js b/Gruntfile.js
index 4f69a8f..7c885d4 100644
--- a/Gruntfile.js
+++ b/Gruntfile.js
@@ -27,7 +27,7 @@
             },
             minifyFds: {
                 files: [{
-                    './platform/core/common/styles/css/fluid-design-system.min.css': ['./platform/core/common/styles/fluid-design-system.scss']
+                    './platform/core/common/styles/css/flow-design-system.min.css': ['./platform/core/common/styles/flow-design-system.scss']
                 }]
             },
             minifyFdsDemo: {
@@ -43,7 +43,7 @@
             fdsStyles: {
                 files: [{
                     expand: true,
-                    src: ['./platform/core/common/styles/css/fluid-design-system.min.css'],
+                    src: ['./platform/core/common/styles/css/flow-design-system.min.css'],
                     dest: './',
                     ext: '.min.css.gz'
                 }]
diff --git a/NOTICE b/NOTICE
index 50b77ff..94b420c 100644
--- a/NOTICE
+++ b/NOTICE
@@ -1,4 +1,4 @@
-Apache NiFi Fluid Design System
+Apache NiFi Flow Design System
 Copyright 2014-2018 The Apache Software Foundation
 
 This product includes software developed at
diff --git a/README.md b/README.md
index bf4825f..5da3b19 100644
--- a/README.md
+++ b/README.md
@@ -1,6 +1,6 @@
-# Apache NiFi Fluid Design System
+# Apache NiFi Flow Design System
 
-The Apache NiFi Fluid Design System module is an atomic reusable platform providing consistent set of UI/UX components for open source friendly web applications to consume. Users can interact with this design system by running the demo-app locally or by visiting: [https://apache.github.io/nifi-fds/](https://apache.github.io/nifi-fds/). This demo application also provides an example of how an Angular application would leverage the nifi-fds NgModule.
+The Apache NiFi Flow Design System module is an atomic reusable platform providing consistent set of UI/UX components for open source friendly web applications to consume. Users can interact with this design system by running the demo-app locally or by visiting: [https://apache.github.io/nifi-fds/](https://apache.github.io/nifi-fds/). This demo application also provides an example of how an Angular application would leverage the nifi-fds NgModule.
 
 #### npm
 
@@ -12,10 +12,10 @@
 
 ## Setup
 
-Import the **Apache NiFi Fluid Design System** NgModule into your angular application:
+Import the **Apache NiFi Flow Design System** NgModule into your angular application:
 
 ```javascript
-var fdsCore = require('fluid-design-system/core');
+var fdsCore = require('flow-design-system/core');
 AppModule.prototype = {
     constructor: AppModule
 };
@@ -62,7 +62,7 @@
 @include fds-theme($fds-theme);
 ```
 
-The Apache NiFi Fluid Design System UI/UX Platform comes with a base CSS file `node_modules/fluid-design-system/core/common/styles/css/fluid-design-system.min.css` (includes icons) that should be included in the head of your HTML document.
+The Apache NiFi Flow Design System UI/UX Platform comes with a base CSS file `node_modules/flow-design-system/core/common/styles/css/flow-design-system.min.css` (includes icons) that should be included in the head of your HTML document.
 
 ## Building
 
@@ -106,7 +106,7 @@
 
 ## Release Managment
 
-For developers with permissions releasing a new version of the NiFi Fluid Design System is simple with [grunt bump](https://github.com/vojtajina/grunt-bump).
+For developers with permissions releasing a new version of the NiFi Flow Design System is simple with [grunt bump](https://github.com/vojtajina/grunt-bump).
 
 ## Deploying github.io demo
 
diff --git a/package.json b/package.json
index aed8a48..fbf33cb 100644
--- a/package.json
+++ b/package.json
@@ -13,10 +13,10 @@
     "test": "./node_modules/protractor/bin/webdriver-manager update --gecko false && karma start karma.conf.js --single-run",
     "test:dev": "./node_modules/protractor/bin/webdriver-manager update --gecko false && karma start karma.conf.js"
   },
-  "description": "The Apache NiFi Fluid Design System module is an atomic reusable platform providing consistent set of UI/UX components for open source friendly web applications to consume.",
-  "module": "./platform/core/fluid-design-system.module.js",
+  "description": "The Apache NiFi Flow Design System module is an atomic reusable platform providing consistent set of UI/UX components for open source friendly web applications to consume.",
+  "module": "./platform/core/flow-design-system.module.js",
   "keywords": [
-    "fluid design system",
+    "flow design system",
     "angular",
     "material",
     "material design",
diff --git a/src/demo-app/components/fluid-design-system/dialogs/demo/fds-demo-dialog.html b/src/demo-app/components/flow-design-system/dialogs/demo/fds-demo-dialog.html
similarity index 100%
rename from src/demo-app/components/fluid-design-system/dialogs/demo/fds-demo-dialog.html
rename to src/demo-app/components/flow-design-system/dialogs/demo/fds-demo-dialog.html
diff --git a/src/demo-app/components/fluid-design-system/dialogs/demo/fds-demo-dialog.js b/src/demo-app/components/flow-design-system/dialogs/demo/fds-demo-dialog.js
similarity index 100%
rename from src/demo-app/components/fluid-design-system/dialogs/demo/fds-demo-dialog.js
rename to src/demo-app/components/flow-design-system/dialogs/demo/fds-demo-dialog.js
diff --git a/src/demo-app/components/fluid-design-system/fds-demo.html b/src/demo-app/components/flow-design-system/fds-demo.html
similarity index 99%
rename from src/demo-app/components/fluid-design-system/fds-demo.html
rename to src/demo-app/components/flow-design-system/fds-demo.html
index 7875daa..e32b36c 100644
--- a/src/demo-app/components/fluid-design-system/fds-demo.html
+++ b/src/demo-app/components/flow-design-system/fds-demo.html
@@ -24,10 +24,10 @@
     </mat-sidenav>
     <div id="fds-demo">
         <mat-card>
-            <mat-card-title class="pad-bottom-sm">Apache NiFi Fluid Design System</mat-card-title>
+            <mat-card-title class="pad-bottom-sm">Apache NiFi Flow Design System</mat-card-title>
             <mat-divider></mat-divider>
             <mat-card-content class="pad-top-sm">
-                <p>With the Apache NiFi Fluid Design System module, we get an atomic, reusable component platform for Apache NiFi and Apache NiFi Registry to consume, while collaborating in an open source model. This module packages the <a class="link" href="https://material.angular.io/components" target="_blank">Angular Material</a> module as well as the <a class="link" href="https://teradata.github.io/covalent/#/components" target="_blank">Teradata Covalent</a> module. These modules have been themed to match the FDS color palette.</p>
+                <p>With the Apache NiFi Flow Design System module, we get an atomic, reusable component platform for Apache NiFi and Apache NiFi Registry to consume, while collaborating in an open source model. This module packages the <a class="link" href="https://material.angular.io/components" target="_blank">Angular Material</a> module as well as the <a class="link" href="https://teradata.github.io/covalent/#/components" target="_blank">Teradata Covalent</a> module. These modules have been themed to match the FDS color palette.</p>
             </mat-card-content>
         </mat-card>
         <mat-card>
@@ -39,7 +39,7 @@
                 <pre lang="javascript">
         <![CDATA[
         var ngCore = require('@angular/core');
-        var fdsCore = require('fluid-design-system/core');
+        var fdsCore = require('flow-design-system/core');
         // other imports
           ...
         new ngCore.NgModule({
@@ -55,7 +55,7 @@
                 <p>HTML:</p>
                 <pre lang="html">
         <![CDATA[
-        <link href="../node_modules/fluid-design-system/core/common/styles/css/fluid-design-system.css" rel="stylesheet">
+        <link href="../node_modules/flow-design-system/core/common/styles/css/flow-design-system.css" rel="stylesheet">
         ]]>
     </pre>
                 <p>Or, if you are using the Angular CLI you will need to add a new entry to the "styles" list in .angular-cli.json.</p>
@@ -63,7 +63,7 @@
                 <pre lang="json">
         <![CDATA[
         "styles": [
-            "../node_modules/fluid-design-system/core/common/styles/fluid-design-system.scss"
+            "../node_modules/flow-design-system/core/common/styles/flow-design-system.scss"
         ]
         ]]>
     </pre>
diff --git a/src/demo-app/components/fluid-design-system/fds-demo.js b/src/demo-app/components/flow-design-system/fds-demo.js
similarity index 98%
rename from src/demo-app/components/fluid-design-system/fds-demo.js
rename to src/demo-app/components/flow-design-system/fds-demo.js
index dcb3d14..3ae86c5 100644
--- a/src/demo-app/components/fluid-design-system/fds-demo.js
+++ b/src/demo-app/components/flow-design-system/fds-demo.js
@@ -20,10 +20,10 @@
 var ngRouter = require('@angular/router');
 var ngMaterial = require('@angular/material');
 var fdsAnimations = require('demo-app/fds.animations.js');
-var fdsDialogsModule = require('@fluid-design-system/dialogs');
-var fdsSnackBarsModule = require('@fluid-design-system/snackbars');
+var fdsDialogsModule = require('@flow-design-system/dialogs');
+var fdsSnackBarsModule = require('@flow-design-system/snackbars');
 var FdsService = require('demo-app/services/fds.service.js');
-var FdsDemoDialog = require('demo-app/components/fluid-design-system/dialogs/demo/fds-demo-dialog.js');
+var FdsDemoDialog = require('demo-app/components/flow-design-system/dialogs/demo/fds-demo-dialog.js');
 
 var NUMBER_FORMAT = function (v) {
     return v;
diff --git a/src/demo-app/fds.module.js b/src/demo-app/fds.module.js
index c9d695d..4b493ed 100644
--- a/src/demo-app/fds.module.js
+++ b/src/demo-app/fds.module.js
@@ -17,10 +17,10 @@
 
 var ngCore = require('@angular/core');
 var FdsRoutes = require('demo-app/fds.routes.js');
-var fdsCore = require('@fluid-design-system/core');
+var fdsCore = require('@flow-design-system/core');
 var Fds = require('demo-app/fds.js');
-var FdsDemo = require('demo-app/components/fluid-design-system/fds-demo.js');
-var FdsDemoDialog = require('demo-app/components/fluid-design-system/dialogs/demo/fds-demo-dialog.js');
+var FdsDemo = require('demo-app/components/flow-design-system/fds-demo.js');
+var FdsDemoDialog = require('demo-app/components/flow-design-system/dialogs/demo/fds-demo-dialog.js');
 var FdsService = require('demo-app/services/fds.service.js');
 var ngCommonHttp = require('@angular/common/http');
 
diff --git a/src/demo-app/fds.routes.js b/src/demo-app/fds.routes.js
index fe81c4f..e6c4de7 100644
--- a/src/demo-app/fds.routes.js
+++ b/src/demo-app/fds.routes.js
@@ -16,7 +16,7 @@
  */
 
 var ngRouter = require('@angular/router');
-var FdsDemo = require('demo-app/components/fluid-design-system/fds-demo.js');
+var FdsDemo = require('demo-app/components/flow-design-system/fds-demo.js');
 
 var FdsRoutes = new ngRouter.RouterModule.forRoot([{
     path: '',
diff --git a/src/demo-app/gh-pages.index.html b/src/demo-app/gh-pages.index.html
index c2be05b..8e3ce02 100644
--- a/src/demo-app/gh-pages.index.html
+++ b/src/demo-app/gh-pages.index.html
@@ -15,13 +15,13 @@
 <!DOCTYPE html>
 <html>
 <head>
-    <title>Apache NiFi Fluid Design System Demo</title>
+    <title>Apache NiFi Flow Design System Demo</title>
     <base href='/nifi-fds/'>
     <meta charset='UTF-8'>
     <meta name='viewport' content='width=device-width, initial-scale=1'>
     <meta http-equiv='Content-Type' content='text/html; charset=UTF-8'/>
     <link rel="stylesheet" href="node_modules/@covalent/core/common/platform.css">
-    <link rel="stylesheet" href='node_modules/nifi-fds/platform/core/common/styles/css/fluid-design-system.min.css'/>
+    <link rel="stylesheet" href='node_modules/nifi-fds/platform/core/common/styles/css/flow-design-system.min.css'/>
     <link rel="stylesheet" href='demo-app/css/fds-demo.min.css'/>
     <link rel='stylesheet' href='node_modules/font-awesome/css/font-awesome.css'/>
 </head>
diff --git a/src/demo-app/gh-pages.package.json b/src/demo-app/gh-pages.package.json
index 17db578..70d842e 100644
--- a/src/demo-app/gh-pages.package.json
+++ b/src/demo-app/gh-pages.package.json
@@ -4,9 +4,9 @@
   "scripts": {
     "start": "./node_modules/http-server/bin/http-server ."
   },
-  "description": "The Apache NiFi Fluid Design System demo provides users with an example web application that consumes the NgModule and allows users to interact with the UI/UX components.",
+  "description": "The Apache NiFi Flow Design System demo provides users with an example web application that consumes the NgModule and allows users to interact with the UI/UX components.",
   "keywords": [
-    "fluid design system",
+    "flow design system",
     "angular",
     "material",
     "material design",
diff --git a/src/demo-app/index.html b/src/demo-app/index.html
index 3eb8f4f..29b0f25 100644
--- a/src/demo-app/index.html
+++ b/src/demo-app/index.html
@@ -15,13 +15,13 @@
 <!DOCTYPE html>
 <html>
 <head>
-    <title>Apache NiFi Fluid Design System Demo</title>
+    <title>Apache NiFi Flow Design System Demo</title>
     <base href='/'>
     <meta charset='UTF-8'>
     <meta name='viewport' content='width=device-width, initial-scale=1'>
     <meta http-equiv='Content-Type' content='text/html; charset=UTF-8'/>
     <link rel="stylesheet" href="node_modules/@covalent/core/common/platform.css">
-    <link rel="stylesheet" href='platform/core/common/styles/css/fluid-design-system.min.css'/>
+    <link rel="stylesheet" href='platform/core/common/styles/css/flow-design-system.min.css'/>
     <link rel="stylesheet" href='demo-app/css/fds-demo.min.css'/>
     <link rel='stylesheet' href='node_modules/font-awesome/css/font-awesome.css'/>
 </head>
diff --git a/src/demo-app/services/fds.service.js b/src/demo-app/services/fds.service.js
index 26e6686..7609ddc 100644
--- a/src/demo-app/services/fds.service.js
+++ b/src/demo-app/services/fds.service.js
@@ -16,8 +16,8 @@
  */
 
 var covalentCore = require('@covalent/core');
-var fdsDialogsModule = require('@fluid-design-system/dialogs');
-var fdsSnackBarsModule = require('@fluid-design-system/snackbars');
+var fdsDialogsModule = require('@flow-design-system/dialogs');
+var fdsSnackBarsModule = require('@flow-design-system/snackbars');
 
 /**
  * FdsService constructor.
@@ -34,7 +34,7 @@
     this.dataTableService = tdDataTableService;
 
     // General
-    this.title = "Apache NiFi Fluid Design System Demo";
+    this.title = "Apache NiFi Flow Design System Demo";
     this.inProgress = true;
     this.perspective = '';
 };
diff --git a/src/platform/core/common/fds-common.module.js b/src/platform/core/common/fds-common.module.js
index 32b5512..88a6355 100644
--- a/src/platform/core/common/fds-common.module.js
+++ b/src/platform/core/common/fds-common.module.js
@@ -16,7 +16,7 @@
  */
 
 var ngCore = require('@angular/core');
-var fdsStorageServiceModule = require('@fluid-design-system/storage-service');
+var fdsStorageServiceModule = require('@flow-design-system/storage-service');
 
 /**
  * FdsCommonsModule constructor.
diff --git a/src/platform/core/common/services/fds-storage.service.spec.js b/src/platform/core/common/services/fds-storage.service.spec.js
index f990af1..3affff0 100644
--- a/src/platform/core/common/services/fds-storage.service.spec.js
+++ b/src/platform/core/common/services/fds-storage.service.spec.js
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-var FdsStorageService = require('@fluid-design-system/common/storage-service');
+var FdsStorageService = require('@flow-design-system/common/storage-service');
 
 describe('FdsStorageService isolated unit tests', function () {
     var fdsStorage;
diff --git a/src/platform/core/common/styles/fluid-design-system.scss b/src/platform/core/common/styles/flow-design-system.scss
similarity index 100%
rename from src/platform/core/common/styles/fluid-design-system.scss
rename to src/platform/core/common/styles/flow-design-system.scss
diff --git a/src/platform/core/dialogs/confirm-dialog/confirm-dialog.component.spec.js b/src/platform/core/dialogs/confirm-dialog/confirm-dialog.component.spec.js
index 0de49e4..b96c0fa 100644
--- a/src/platform/core/dialogs/confirm-dialog/confirm-dialog.component.spec.js
+++ b/src/platform/core/dialogs/confirm-dialog/confirm-dialog.component.spec.js
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-var FdsConfirmDialogComponent = require('@fluid-design-system/confirm-dialog-component');
+var FdsConfirmDialogComponent = require('@flow-design-system/confirm-dialog-component');
 
 describe('coasterComponent isolated unit tests', function () {
     var fdsConfirmDialogComponent;
diff --git a/src/platform/core/dialogs/fds-dialogs.component.spec.js b/src/platform/core/dialogs/fds-dialogs.component.spec.js
index a8c6913..3bf3e5b 100644
--- a/src/platform/core/dialogs/fds-dialogs.component.spec.js
+++ b/src/platform/core/dialogs/fds-dialogs.component.spec.js
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-var fdsDialogsComponent = require('@fluid-design-system/dialog-component');
+var fdsDialogsComponent = require('@flow-design-system/dialog-component');
 
 describe('FdsDialogComponent isolated unit tests', function () {
     var fdsDialogs;
diff --git a/src/platform/core/dialogs/fds-dialogs.module.js b/src/platform/core/dialogs/fds-dialogs.module.js
index 3758655..31b0306 100644
--- a/src/platform/core/dialogs/fds-dialogs.module.js
+++ b/src/platform/core/dialogs/fds-dialogs.module.js
@@ -20,9 +20,9 @@
 var ngFlex = require('@angular/flex-layout');
 var ngCommon = require('@angular/common');
 var ngForms = require('@angular/forms');
-var fdsDialogComponentModule = require('@fluid-design-system/dialog-component');
-var fdsDialogServiceModule = require('@fluid-design-system/dialog-service');
-var FdsConfirmDialogComponent = require('@fluid-design-system/confirm-dialog-component');
+var fdsDialogComponentModule = require('@flow-design-system/dialog-component');
+var fdsDialogServiceModule = require('@flow-design-system/dialog-service');
+var FdsConfirmDialogComponent = require('@flow-design-system/confirm-dialog-component');
 
 var FDS_DIALOGS = [
     fdsDialogComponentModule.FdsDialogComponent,
diff --git a/src/platform/core/dialogs/services/dialog.service.js b/src/platform/core/dialogs/services/dialog.service.js
index 985baf5..9f3736f 100644
--- a/src/platform/core/dialogs/services/dialog.service.js
+++ b/src/platform/core/dialogs/services/dialog.service.js
@@ -17,7 +17,7 @@
 
 var ngCore = require('@angular/core');
 var ngMaterial = require('@angular/material');
-var FdsConfirmDialogComponent = require('@fluid-design-system/confirm-dialog-component');
+var FdsConfirmDialogComponent = require('@flow-design-system/confirm-dialog-component');
 
 function IDialogConfig() {
     this.title = '';
diff --git a/src/platform/core/fluid-design-system.module.js b/src/platform/core/flow-design-system.module.js
similarity index 94%
rename from src/platform/core/fluid-design-system.module.js
rename to src/platform/core/flow-design-system.module.js
index 7a7aaec..9623c28 100644
--- a/src/platform/core/fluid-design-system.module.js
+++ b/src/platform/core/flow-design-system.module.js
@@ -23,15 +23,15 @@
 var ngPlatformBrowser = require('@angular/platform-browser');
 var ngAnimations = require('@angular/platform-browser/animations');
 var covalentCore = require('@covalent/core');
-var fdsDialogsModule = require('@fluid-design-system/dialogs');
-var fdsSnackBarsModule = require('@fluid-design-system/snackbars');
+var fdsDialogsModule = require('@flow-design-system/dialogs');
+var fdsSnackBarsModule = require('@flow-design-system/snackbars');
 
 /**
- * FluidDesignSystemModule constructor.
+ * FlowDesignSystemModule constructor.
  *
  * @constructor
  */
-function FluidDesignSystemModule() {
+function FlowDesignSystemModule() {
     $(document).ready(function () {
         //add fds attr to body tag to allow fine grain style overrides
         document.body.setAttribute('fds', '');
@@ -46,11 +46,11 @@
     });
 };
 
-FluidDesignSystemModule.prototype = {
-    constructor: FluidDesignSystemModule
+FlowDesignSystemModule.prototype = {
+    constructor: FlowDesignSystemModule
 };
 
-FluidDesignSystemModule.annotations = [
+FlowDesignSystemModule.annotations = [
     new ngCore.NgModule({
         imports: [
             ngFlex.FlexLayoutModule,
@@ -152,4 +152,4 @@
         ]
     })
 ];
-module.exports = FluidDesignSystemModule;
+module.exports = FlowDesignSystemModule;
diff --git a/src/platform/core/snackbars/coaster/coaster.component.spec.js b/src/platform/core/snackbars/coaster/coaster.component.spec.js
index 0959791..ab8be9e 100644
--- a/src/platform/core/snackbars/coaster/coaster.component.spec.js
+++ b/src/platform/core/snackbars/coaster/coaster.component.spec.js
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-var CoasterComponent = require('@fluid-design-system/coaster-component');
+var CoasterComponent = require('@flow-design-system/coaster-component');
 
 describe('coasterComponent isolated unit tests', function () {
     var coaster;
diff --git a/src/platform/core/snackbars/fds-snackbar.component.spec.js b/src/platform/core/snackbars/fds-snackbar.component.spec.js
index 355af94..c8c8e78 100644
--- a/src/platform/core/snackbars/fds-snackbar.component.spec.js
+++ b/src/platform/core/snackbars/fds-snackbar.component.spec.js
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-var fdsSnackBarComponent = require('@fluid-design-system/snackbar-component');
+var fdsSnackBarComponent = require('@flow-design-system/snackbar-component');
 
 describe('FdsSnackBarComponent isolated unit tests', function () {
     var fdsSnackBar;
diff --git a/src/platform/core/snackbars/fds-snackbars.module.js b/src/platform/core/snackbars/fds-snackbars.module.js
index 657b1ae..c3c5b5b 100644
--- a/src/platform/core/snackbars/fds-snackbars.module.js
+++ b/src/platform/core/snackbars/fds-snackbars.module.js
@@ -20,9 +20,9 @@
 var ngFlex = require('@angular/flex-layout');
 var ngCommon = require('@angular/common');
 var ngForms = require('@angular/forms');
-var fdsSnackBarComponentModule = require('@fluid-design-system/snackbar-component');
-var fdsSnackBarServiceModule = require('@fluid-design-system/snackbar-service');
-var FdsCoasterComponent = require('@fluid-design-system/coaster-component');
+var fdsSnackBarComponentModule = require('@flow-design-system/snackbar-component');
+var fdsSnackBarServiceModule = require('@flow-design-system/snackbar-service');
+var FdsCoasterComponent = require('@flow-design-system/coaster-component');
 
 var FDS_SNACKBARS = [
     fdsSnackBarComponentModule.FdsSnackBarComponent,
diff --git a/src/platform/core/snackbars/services/snackbar.service.js b/src/platform/core/snackbars/services/snackbar.service.js
index e02e505..1311011 100644
--- a/src/platform/core/snackbars/services/snackbar.service.js
+++ b/src/platform/core/snackbars/services/snackbar.service.js
@@ -17,7 +17,7 @@
 
 var ngCore = require('@angular/core');
 var ngMaterial = require('@angular/material');
-var FdsCoasterComponent = require('@fluid-design-system/coaster-component');
+var FdsCoasterComponent = require('@flow-design-system/coaster-component');
 var $ = require('jquery');
 
 function ISnackBarConfig() {
diff --git a/test/karma.conf.js b/test/karma.conf.js
index 19f0125..929ce85 100644
--- a/test/karma.conf.js
+++ b/test/karma.conf.js
@@ -75,7 +75,7 @@
             {pattern: appBase + 'systemjs.spec.config.js', included: false, watched: false},
             'karma-test-shim.js', // optionally extend SystemJS mapping e.g., with barrels
 
-            // Include the Fluid Design System templates in the test suite.
+            // Include the Flow Design System templates in the test suite.
             {
                 pattern: 'platform/core/**/*.html',
                 included: true,
diff --git a/src/demo-app/gh-pages.systemjs.config.js b/src/demo-app/gh-pages.systemjs.config.js
index 3b6b6ae..3fc22e9 100644
--- a/src/demo-app/gh-pages.systemjs.config.js
+++ b/src/demo-app/gh-pages.systemjs.config.js
@@ -97,16 +97,16 @@
             'querystring': 'npm:querystring',
             'tslib': 'npm:tslib/tslib.js',
 
-            // Fluid Design System
-            '@fluid-design-system/core': 'npm:nifi-fds/platform/core/fluid-design-system.module.js',
-            '@fluid-design-system/dialogs': 'npm:nifi-fds/platform/core/dialogs/fds-dialogs.module.js',
-            '@fluid-design-system/dialog-component': 'npm:nifi-fds/platform/core/dialogs/fds-dialog.component.js',
-            '@fluid-design-system/dialog-service': 'npm:nifi-fds/platform/core/dialogs/services/dialog.service.js',
-            '@fluid-design-system/confirm-dialog-component': 'npm:nifi-fds/platform/core/dialogs/confirm-dialog/confirm-dialog.component.js',
-            '@fluid-design-system/snackbars': 'npm:nifi-fds/platform/core/snackbars/fds-snackbars.module.js',
-            '@fluid-design-system/snackbar-component': 'npm:nifi-fds/platform/core/snackbars/fds-snackbar.component.js',
-            '@fluid-design-system/snackbar-service': 'npm:nifi-fds/platform/core/snackbars/services/snackbar.service.js',
-            '@fluid-design-system/coaster-component': 'npm:nifi-fds/platform/core/snackbars/coaster/coaster.component.js'
+            // Flow Design System
+            '@flow-design-system/core': 'npm:nifi-fds/platform/core/flow-design-system.module.js',
+            '@flow-design-system/dialogs': 'npm:nifi-fds/platform/core/dialogs/fds-dialogs.module.js',
+            '@flow-design-system/dialog-component': 'npm:nifi-fds/platform/core/dialogs/fds-dialog.component.js',
+            '@flow-design-system/dialog-service': 'npm:nifi-fds/platform/core/dialogs/services/dialog.service.js',
+            '@flow-design-system/confirm-dialog-component': 'npm:nifi-fds/platform/core/dialogs/confirm-dialog/confirm-dialog.component.js',
+            '@flow-design-system/snackbars': 'npm:nifi-fds/platform/core/snackbars/fds-snackbars.module.js',
+            '@flow-design-system/snackbar-component': 'npm:nifi-fds/platform/core/snackbars/fds-snackbar.component.js',
+            '@flow-design-system/snackbar-service': 'npm:nifi-fds/platform/core/snackbars/services/snackbar.service.js',
+            '@flow-design-system/coaster-component': 'npm:nifi-fds/platform/core/snackbars/coaster/coaster.component.js'
         },
         // packages tells the System loader how to load when no filename and/or no extension
         packages: {
diff --git a/src/demo-app/systemjs.config.js b/src/demo-app/systemjs.config.js
index a3afaf3..8065cca 100644
--- a/src/demo-app/systemjs.config.js
+++ b/src/demo-app/systemjs.config.js
@@ -97,17 +97,17 @@
             'querystring': 'npm:querystring',
             'tslib': 'npm:tslib/tslib.js',
 
-            // Fluid Design System
-            '@fluid-design-system/core': 'platform/core/fluid-design-system.module.js',
-            '@fluid-design-system/dialogs': 'platform/core/dialogs/fds-dialogs.module.js',
-            '@fluid-design-system/dialog-component': 'platform/core/dialogs/fds-dialog.component.js',
-            '@fluid-design-system/dialog-service': 'platform/core/dialogs/services/dialog.service.js',
-            '@fluid-design-system/confirm-dialog-component': 'platform/core/dialogs/confirm-dialog/confirm-dialog.component.js',
-            '@fluid-design-system/snackbars': 'platform/core/snackbars/fds-snackbars.module.js',
-            '@fluid-design-system/snackbar-component': 'platform/core/snackbars/fds-snackbar.component.js',
-            '@fluid-design-system/snackbar-service': 'platform/core/snackbars/services/snackbar.service.js',
-            '@fluid-design-system/coaster-component': 'platform/core/snackbars/coaster/coaster.component.js',
-            '@fluid-design-system/common/storage-service': 'platform/core/common/services/fds-storage.service.js'
+            // Flow Design System
+            '@flow-design-system/core': 'platform/core/flow-design-system.module.js',
+            '@flow-design-system/dialogs': 'platform/core/dialogs/fds-dialogs.module.js',
+            '@flow-design-system/dialog-component': 'platform/core/dialogs/fds-dialog.component.js',
+            '@flow-design-system/dialog-service': 'platform/core/dialogs/services/dialog.service.js',
+            '@flow-design-system/confirm-dialog-component': 'platform/core/dialogs/confirm-dialog/confirm-dialog.component.js',
+            '@flow-design-system/snackbars': 'platform/core/snackbars/fds-snackbars.module.js',
+            '@flow-design-system/snackbar-component': 'platform/core/snackbars/fds-snackbar.component.js',
+            '@flow-design-system/snackbar-service': 'platform/core/snackbars/services/snackbar.service.js',
+            '@flow-design-system/coaster-component': 'platform/core/snackbars/coaster/coaster.component.js',
+            '@flow-design-system/common/storage-service': 'platform/core/common/services/fds-storage.service.js'
         },
         // packages tells the System loader how to load when no filename and/or no extension
         packages: {
diff --git a/src/platform/systemjs.spec.config.js b/src/platform/systemjs.spec.config.js
index 1f51a7a..f6ac758 100644
--- a/src/platform/systemjs.spec.config.js
+++ b/src/platform/systemjs.spec.config.js
@@ -93,17 +93,17 @@
             'rxjs': 'npm:rxjs',
             'zone.js': 'npm:zone.js/dist/zone.js',
 
-            // Fluid Design System
-            '@fluid-design-system/core': 'platform/core/fluid-design-system.module.js',
-            '@fluid-design-system/dialogs': 'platform/core/dialogs/fds-dialogs.module.js',
-            '@fluid-design-system/dialog-component': 'platform/core/dialogs/fds-dialog.component.js',
-            '@fluid-design-system/dialog-service': 'platform/core/dialogs/services/dialog.service.js',
-            '@fluid-design-system/confirm-dialog-component': 'platform/core/dialogs/confirm-dialog/confirm-dialog.component.js',
-            '@fluid-design-system/snackbars': 'platform/core/snackbars/fds-snackbars.module.js',
-            '@fluid-design-system/snackbar-component': 'platform/core/snackbars/fds-snackbar.component.js',
-            '@fluid-design-system/snackbar-service': 'platform/core/snackbars/services/snackbar.service.js',
-            '@fluid-design-system/coaster-component': 'platform/core/snackbars/coaster/coaster.component.js',
-            '@fluid-design-system/common/storage-service': 'platform/core/common/services/fds-storage.service.js'
+            // Flow Design System
+            '@flow-design-system/core': 'platform/core/flow-design-system.module.js',
+            '@flow-design-system/dialogs': 'platform/core/dialogs/fds-dialogs.module.js',
+            '@flow-design-system/dialog-component': 'platform/core/dialogs/fds-dialog.component.js',
+            '@flow-design-system/dialog-service': 'platform/core/dialogs/services/dialog.service.js',
+            '@flow-design-system/confirm-dialog-component': 'platform/core/dialogs/confirm-dialog/confirm-dialog.component.js',
+            '@flow-design-system/snackbars': 'platform/core/snackbars/fds-snackbars.module.js',
+            '@flow-design-system/snackbar-component': 'platform/core/snackbars/fds-snackbar.component.js',
+            '@flow-design-system/snackbar-service': 'platform/core/snackbars/services/snackbar.service.js',
+            '@flow-design-system/coaster-component': 'platform/core/snackbars/coaster/coaster.component.js',
+            '@flow-design-system/common/storage-service': 'platform/core/common/services/fds-storage.service.js'
         },
         // packages tells the System loader how to load when no filename and/or no extension
         packages: {